# Installation


## Stable release

To install Stochastic Matching, run this command in your terminal:

```console
$ pip install stochastic_matching
```

This is the preferred method to install Stochastic Matching, as it will always install the most recent stable release.

If you don't have [pip] installed, this [Python installation guide] can guide
you through the process.


## From sources

The sources for Stochastic Matching can be downloaded from the [GitHub repo].

You can either clone the public repository:

```console
$ git clone git://github.com/balouf/stochastic_matching
```

Or download the [tarball]:

```console
$ curl -OJL https://github.com/balouf/stochastic_matching/tarball/master
```

Once you have a copy of the source, you can install it with:

```console
$ pip install .
```

[Python installation guide]: <http://docs.python-guide.org/en/latest/starting/installation/>
[pip]: <https://pip.pypa.io>
[GitHub repo]: <https://github.com/balouf/stochastic_matching>
[tarball]: <https://github.com/balouf/stochastic_matching/tarball/master>
